@@ -120,7 +120,7 @@ def count_points(pts: Union[geometry.Point, geometry.MultiPoint]) -> int:
         raise TypeError
 
 
-def inner_intersection(poly, pts):
+def inner_intersection(poly: geometry.Polygon, pts: geometry.MultiPoint) -> Union[geometry.Point, geometry.MultiPoint]:
     intersec = poly.intersection(pts)
     intersec_bound = poly.boundary.intersection(intersec)
     return intersec.difference(intersec_bound)
@@ -337,14 +337,18 @@ def trace_tight(polygon: Union[geometry.Polygon, geometry.MultiPolygon],
         nregions = 1
         polygon = geometry.MultiPolygon([polygon])
     else:
-        nregions = len(polygon)
+        nregions = len(polygon.geoms)
 
     z_points = geometry.MultiPoint(Z)
     splits = []
 
     for i in range(nregions):
-        criteria = inner_intersection(polygon[i], z_points)
-        polydata = np.array(criteria)
+        criteria = inner_intersection(polygon.geoms[i], z_points)
+        if criteria.type == 'Point':
+            polydata = np.array(criteria.coords)
+        else:
+            polydata = np.vstack([np.array(p.coords) for p in criteria.geoms])
+
         if polydata.shape[0] < 3:
             continue
 
